==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/NativeUIIconButton.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { NativeUIButton } from "./NativeUIButton";
import { markType } from "./type";
/**
 * @hidden
 */
var NativeUIIconButton = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NativeUIIconButton, _super);
    function NativeUIIconButton() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    NativeUIIconButton.prototype.get_c = function () {
        return 10;
    };
    Object.defineProperty(NativeUIIconButton.prototype, "ax", {
        get: function () {
            var a = this.o(13);
            return a;
        },
        set: function (a) {
            this.af(13, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIIconButton.prototype, "ay", {
        get: function () {
            var a = this.o(14);
            return a;
        },
        set: function (a) {
            this.af(14, a);
        },
        enumerable: false,
        configurable: true
    });
    NativeUIIconButton.$t = markType(NativeUIIconButton, 'NativeUIIconButton', NativeUIButton.$);
    return NativeUIIconButton;
}(NativeUIButton));
export { NativeUIIconButton };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/NativeUIIconButton.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { NativeUIButton } from "./NativeUIButton";
import { markType } from "./type";
/**
 * @hidden
 */
var NativeUIIconButton = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NativeUIIconButton, _super);
    function NativeUIIconButton() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    NativeUIIconButton.prototype.get_e = function () {
        return 10;
    };
    Object.defineProperty(NativeUIIconButton.prototype, "a2", {
        get: function () {
            var a = this.q(13);
            return a;
        },
        set: function (a) {
            this.ak(13, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIIconButton.prototype, "a3", {
        get: function () {
            var a = this.q(14);
            return a;
        },
        set: function (a) {
            this.ak(14, a);
        },
        enumerable: false,
        configurable: true
    });
    NativeUIIconButton.$t = markType(NativeUIIconButton, 'NativeUIIconButton', NativeUIButton.$);
    return NativeUIIconButton;
}(NativeUIButton));
export { NativeUIIconButton };
